# Generated by Django 3.1.8 on 2021-04-30 09:30

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("aadiscordbot", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="RssFeeds",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(default="", max_length=254)),
                ("url", models.CharField(default="", max_length=254)),
                (
                    "discord_channel",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to="aadiscordbot.channels",
                    ),
                ),
            ],
            options={
                "verbose_name": "RSS Feed",
                "verbose_name_plural": "RSS Feeds",
                "default_permissions": (),
            },
        ),
        migrations.CreateModel(
            name="LastItem",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "rss_item_time",
                    models.CharField(blank=True, default="", max_length=254),
                ),
                ("rss_item_title", models.CharField(default="", max_length=254)),
                ("rss_item_link", models.CharField(default="", max_length=254)),
                (
                    "rss_item_guid",
                    models.CharField(blank=True, default="", max_length=254),
                ),
                (
                    "rss_feed",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="+",
                        to="aa_rss_to_discord.rssfeeds",
                    ),
                ),
            ],
            options={
                "verbose_name": "Last Item",
                "verbose_name_plural": "Last Items",
                "default_permissions": (),
            },
        ),
    ]
