# Generated by Django 3.2.3 on 2021-05-25 08:21

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aa_rss_to_discord", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="rssfeeds",
            name="enabled",
            field=models.BooleanField(default=True),
        ),
    ]
